sqltriples.Query.ConjunctionOfTuples

Package sqltriples :: Module Query :: Class ConjunctionOfTuples |
[show private | hide private]
[frames | no frames]

## Class ConjunctionOfTuples

          CombinedResults --+
                            |
                  Conjunction --+
                                |
    AbstractQuery --+           |
                    |           |
                Query --+       |
                        |       |
                  Results --+   |
                            |   |
                       Tuples --+
                                |
                               ConjunctionOfTuples

Method Summary
| `__init__(self, store, queries, pattern)`
Inherited from CombinedResults
| ``get_query`(self, index)`
| ``get_subquery`(self, parent_columns, parent_index, index, match_first, match_parent, match_child)`
Inherited from Tuples
| ``_get_exposed_columns`(self)` Return the extended exposed columns for the pattern.
| ``_get_results`(self, results)` Return the 'results' for the retrieved tuples.
Inherited from Results
| ``_get_joins`(self, index)` Add joins where the result needs them: ...
| ``_get_order_column`(self, index)`
| ``_get_order_direction`(self, index)`
| ``_get_order_extent`(self)`
| ``_get_query`(self, select_clause, index, new_index, constraints, constraint_values)` Build the query conditions and return a usable query which starts with the supplied 'select_clause' and which uses the given table 'index' number as qualifier.
Inherited from Query
| ``__getitem__`(self, i)`
| ``__len__`(self)`
| ``__repr__`(self)`
| ``_apply_function`(self, fn, column)`
| ``_ensure`(self)` Ensure the the query has been executed.
| ``_execute`(self)` Execute the query, generated by this object's 'get_query' method, and return the results in a form produced by this object's '_get_results' method.
| ``_get_columns`(self, exposed_columns, index, limited_to)` Return a column selection for the 'exposed_columns' qualified by the given table 'index', optionally limited by the given 'limited_to' sequence of column definitions.
| ``_get_join_constraints`(self, parent_columns, child_columns, parent_index, child_index)`
| ``_get_table`(self, index)`

Class Variable Summary
Inherited from Conjunction
`int` | `in_parentheses` = 1
`str` | `operator` = `'and'`
Inherited from Tuples
`list` | `exposed_columns` = `[('subject', 'subject_type'), ('predic...`
Inherited from AbstractQuery
`list` | `table_columns` = `[('subject', 'subject_type', 0), ('predi...`

Generated by Epydoc 2.1 on Sat Sep 30 00:54:36 2006 | http://epydoc.sf.net